@@ -348,6 +348,28 @@ class DirectChannel(RequestWrapper):
         headers = {'content-type': 'application/json'}
         url = "{0}/{1}".format(self.url, 'wsc_save_activity.ashx')
         return self._handle_data(self._send_request(url=url, payload=payload, headers=headers, debug=self.debug))
+    
+    def wsc_close_activity(self, idattivita=None, note=None, datachiusura=None, orachiusura=None,
+                          codiceesito=None, coodicemotivorifiutoask=None):
+        payload = {
+            "env": self.env,
+            "application": self.application,
+            "operation": "save",
+            "token": self.token,
+            "user": self.user,
+            "param": "",
+            "data": {
+                "idAttivita": idattivita,
+                "note": note,
+                "dataChiusura": datachiusura,
+                "oraChiusura": orachiusura,
+                "codiceEsito": codiceesito,
+                "codiceMotivoRifiutoAsk": coodicemotivorifiutoask,
+            }
+        }
+        headers = {'content-type': 'application/json'}
+        url = "{0}/{1}".format(self.url, 'wsc_close_activity.ashx')
+        return self._handle_data(self._send_request(url=url, payload=payload, headers=headers, debug=self.debug))
 
     def wsc_save_privacy(self, codicedonatore, codiceprivacy, attiva, dataentrata, datauscita, note):
         payload = {
